@@ -219,8 +219,6 @@ void MdApi::OnRtnForQuoteRsp(CThostFtdcForQuoteRspField *pForQuoteRsp)
 	this->task_queue.push(task);
 };
 
-
-
 ///-------------------------------------------------------------------------------------
 ///̴߳ӶȡݣתΪpython󣬽
 ///-------------------------------------------------------------------------------------
@@ -358,6 +356,8 @@ void MdApi::processRspUserLogin(Task *task)
 		data["CZCETime"] = toUtf(task_data->CZCETime);
 		data["FFEXTime"] = toUtf(task_data->FFEXTime);
 		data["INETime"] = toUtf(task_data->INETime);
+		data["SysVersion"] = toUtf(task_data->SysVersion);
+		data["GFEXTime"] = toUtf(task_data->GFEXTime);
 		delete task_data;
 	}
 	dict error;
@@ -575,6 +575,8 @@ void MdApi::processRtnDepthMarketData(Task *task)
 		data["ActionDay"] = toUtf(task_data->ActionDay);
 		data["InstrumentID"] = toUtf(task_data->InstrumentID);
 		data["ExchangeInstID"] = toUtf(task_data->ExchangeInstID);
+		data["BandingUpperPrice"] = task_data->BandingUpperPrice;
+		data["BandingLowerPrice"] = task_data->BandingLowerPrice;
 		delete task_data;
 	}
 	this->onRtnDepthMarketData(data);
@@ -599,7 +601,6 @@ void MdApi::processRtnForQuoteRsp(Task *task)
 	this->onRtnForQuoteRsp(data);
 };
 
-
 ///-------------------------------------------------------------------------------------
 ///
 ///-------------------------------------------------------------------------------------
@@ -647,11 +648,32 @@ string MdApi::getTradingDay()
 	return day;
 };
 
+string MdApi::getApiVersion()
+{
+	string version = this->api->GetApiVersion();
+	return version;
+};
+
 void MdApi::registerFront(string pszFrontAddress)
 {
 	this->api->RegisterFront((char*)pszFrontAddress.c_str());
 };
 
+void MdApi::registerNameServer(string pszNsAddress)
+{
+	this->api->RegisterNameServer((char*)pszNsAddress.c_str());
+};
+
+void MdApi::registerFensUserInfo(const dict &req)
+{
+	CThostFtdcFensUserInfoField myreq = CThostFtdcFensUserInfoField();
+	memset(&myreq, 0, sizeof(myreq));
+	getString(req, "BrokerID", myreq.BrokerID);
+	getString(req, "UserID", myreq.UserID);
+	getChar(req, "LoginMode", &myreq.LoginMode);
+	this->api->RegisterFensUserInfo(&myreq);
+};
+
 int MdApi::subscribeMarketData(string instrumentID)
 {
 	char* buffer = (char*) instrumentID.c_str();
@@ -663,7 +685,7 @@ int MdApi::subscribeMarketData(string instrumentID)
 int MdApi::unSubscribeMarketData(string instrumentID)
 {
 	char* buffer = (char*)instrumentID.c_str();
-	char* myreq[1] = { buffer };;
+	char* myreq[1] = { buffer };
 	int i = this->api->UnSubscribeMarketData(myreq, 1);
 	return i;
 };
@@ -679,7 +701,7 @@ int MdApi::subscribeForQuoteRsp(string instrumentID)
 int MdApi::unSubscribeForQuoteRsp(string instrumentID)
 {
 	char* buffer = (char*)instrumentID.c_str();
-	char* myreq[1] = { buffer };;
+	char* myreq[1] = { buffer };
 	int i = this->api->UnSubscribeForQuoteRsp(myreq, 1);
 	return i;
 };
@@ -726,7 +748,6 @@ int MdApi::reqQryMulticastInstrument(const dict &req, int reqid)
 	return i;
 };
 
-
 ///-------------------------------------------------------------------------------------
 ///Boost.Pythonװ
 ///-------------------------------------------------------------------------------------
@@ -906,6 +927,8 @@ PYBIND11_MODULE(vnctpmd, m)
 		.def("exit", &MdApi::exit)
 		.def("getTradingDay", &MdApi::getTradingDay)
 		.def("registerFront", &MdApi::registerFront)
+		.def("registerNameServer", &MdApi::registerNameServer)
+		.def("registerFensUserInfo", &MdApi::registerFensUserInfo)
 		.def("subscribeMarketData", &MdApi::subscribeMarketData)
 		.def("unSubscribeMarketData", &MdApi::unSubscribeMarketData)
 		.def("subscribeForQuoteRsp", &MdApi::subscribeForQuoteRsp)
